<?php

// Settings for the Layoutstudio WORKING_COPY theme

// Include the definition of layoutstudio_settings() and layoutstudio_theme_get_default_settings().
include_once './' . drupal_get_path('theme', 'layoutstudio') . '/theme-settings.php';

/**
 * Implementation of THEMEHOOK_settings() function.
 *
 * @param $saved_settings
 *   An array of saved settings for this theme.
 * @return
 *   A form array.
 */
function WORKING_COPY_settings($saved_settings) {
	
  // Get the default values from the .info file.
  $defaults = layoutstudio_theme_get_default_settings('WORKING_COPY');

  // Merge the saved variables and their default values.
  $settings = array_merge($defaults, $saved_settings);

  /*
   * Create the form using Forms API: http://api.drupal.org/api/6
   */
  $form = array();
  
  $form['layoutstudio_layouts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Layout'),
    '#description' => t('<p>Choose a predefined layout for the Primary, Secondary and Tertiary regions of the site. Once you have chosen a layout, edit the corresponding css file in the <em>' . base_path() . path_to_theme() . '/layout</em> directory. For example, if you choose Layout #4, edit the <em>layout4.css</em>.<p>
      <p style="margin-bottom: 0;">Color reference for Primary, Secondary & Tertiary regions:</p>
      <ul class="color-reference layouts">
            <li class="region-primary">Primary</li>
            <li class="region-secondary">Secondary</li>
            <li class="region-tertiary">Tertiary</li>
      </ul class="color-reference">
    '),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  
  $layout_path = drupal_get_path("theme","WORKING_COPY")."/layouts";
  $form['layoutstudio_layouts']['layoutstudio_layout'] = array(
    '#type' => 'radios',              
    '#options' => array(
      "layout1" => t('<strong>Layout #1</strong>') . theme("image",$layout_path."/layout1.png") . t('<span class="layout-type")>Three column layout with secondary on the left and tertiary on the right of the main content area.</span>'),
      "layout2" => t('<strong>Layout #2</strong>') . theme("image",$layout_path."/layout2.png") . t('<span class="layout-type")>Three column layout with tertiary on the left and secondary on the right of the main content area.</span>'),
      "layout3" => t('<strong>Layout #3</strong>') . theme("image",$layout_path."/layout3.png") . t('<span class="layout-type")>Three column layout with secondary and tertiary to the right of the main content area.</span>'),
      "layout4" => t('<strong>Layout #4</strong>') . theme("image",$layout_path."/layout4.png") . t('<span class="layout-type")>Two column layout with secondary and tertiary on the right of the main content area. Tertiary is below secondary</span>'),
      "layout5" => t('<strong>Layout #5</strong>') . theme("image",$layout_path."/layout5.png") . t('<span class="layout-type")>Two column layout with secondary and tertiary on the left of the main content area. Tertiary is below secondary</span>'),
      "layout6" => t('<strong>Layout #6</strong>') . theme("image",$layout_path."/layout6.png") . t('<span class="layout-type")>One column layout with the secondary and tertiary split below the main content area.</span>'),
      "layout7" => t('<strong>Layout #7</strong>') . theme("image",$layout_path."/layout7.png") . t('<span class="layout-type")>Three column layout with tertiary and secondary on the right of the main content area.</span>'),
      "layout8" => t('<strong>Layout #8</strong>') . theme("image",$layout_path."/layout8.png") . t('<span class="layout-type")>Three column layout with secondary and tertiary on the left of the main content area.</span>'),
      "layout9" => t('<strong>Layout #9</strong>') . theme("image",$layout_path."/layout9.png") . t('<span class="layout-type")>Three column layout with tertiary and secondary on the left of the main content area.</span>'),
    ),
    '#default_value' => $settings['layoutstudio_layout'],
    '#attributes' => array('class' => 'layouts'),
  );
  
  /* -- Delete this line if you want to use this setting
  $form['WORKING_COPY_example'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Use this sample setting'),
    '#default_value' => $settings['WORKING_COPY_example'],
    '#description'   => t("This option doesn't do anything; it's just an example."),
  );
  // */

  // Add the base theme's settings.
  $form += layoutstudio_settings($saved_settings, $defaults);

  // Return the form
  return $form;
}
